==> members-facade-2.2.8-20211210.025046-6-sources.jar: com/bizvane/members/facade/models/po/MbrLevelRechargePO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrLevelRechargePO implements Serializable {

	/**
	 * 只读. 付费卡主键id. level_recharge_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "付费卡主键id", name = "levelRechargeId", required = false, example = "")
	private Long levelRechargeId;
	/**
	 * 只读. 公司id. sys_company_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "公司id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 品牌id. brand_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. 会员code. member_code
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员code", name = "memberCode", required = false, example = "")
	private String memberCode;
	/**
	 * 只读. 名称. name
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "名称", name = "name", required = false, example = "")
	private String name;
	/**
	 * 只读. 卡号. card_no
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "卡号", name = "cardNo", required = false, example = "")
	private String cardNo;
	/**
	 * 只读. . phone
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "phone", required = false, example = "")
	private String phone;
	/**
	 * 只读. 充值等级. level_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "充值等级", name = "levelId", required = false, example = "")
	private Long levelId;
	/**
	 * 只读. 到期等级变更. change_level_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "到期等级变更", name = "changeLevelId", required = false, example = "")
	private Long changeLevelId;

	@io.swagger.annotations.ApiModelProperty(value = "第一次充值前的等级ID", name = "firstRechargeLevelId")
	private Long firstRechargeLevelId;
	/**
	 * 只读. 有效期. effective_date
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "有效期", name = "effectiveDate", required = false, example = "")
	private Date effectiveDate;
	/**
	 * 只读. 数据有效性 0无效 1有效. valid
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性 0无效 1有效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 备注. remark
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人名称. create_user_name
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人名称", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建日期. create_date
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人姓名. modified_user_name
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人姓名", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改日期. modified_date
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改日期", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getLevelRechargeId() {
		return levelRechargeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setLevelRechargeId(Long levelRechargeId) {
		this.levelRechargeId = levelRechargeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getName() {
		return name;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setName(String name) {
		this.name = name == null ? null : name.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getCardNo() {
		return cardNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setCardNo(String cardNo) {
		this.cardNo = cardNo == null ? null : cardNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getPhone() {
		return phone;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setPhone(String phone) {
		this.phone = phone == null ? null : phone.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getLevelId() {
		return levelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setLevelId(Long levelId) {
		this.levelId = levelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getChangeLevelId() {
		return changeLevelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setChangeLevelId(Long changeLevelId) {
		this.changeLevelId = changeLevelId;
	}

	public Long getFirstRechargeLevelId() {
		return firstRechargeLevelId;
	}

	public void setFirstRechargeLevelId(Long firstRechargeLevelId) {
		this.firstRechargeLevelId = firstRechargeLevelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Date getEffectiveDate() {
		return effectiveDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}
}

==> members-facade-20250930-20250909.101021-1-sources.jar: com/bizvane/members/facade/models/po/MbrLevelRechargePO.java <==
package com.bizvane.members.facade.models.po;

import com.bizvane.members.facade.utils.EncryptCardNo;
import com.bizvane.members.facade.utils.EncryptPhone;

import java.io.Serializable;
import java.util.Date;

@EncryptPhone
public class MbrLevelRechargePO implements Serializable {

	/**
	 * 只读. 付费卡主键id. level_recharge_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "付费卡主键id", name = "levelRechargeId", required = false, example = "")
	private Long levelRechargeId;
	/**
	 * 只读. 公司id. sys_company_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "公司id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 品牌id. brand_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. 会员code. member_code
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员code", name = "memberCode", required = false, example = "")
	private String memberCode;
	/**
	 * 只读. 名称. name
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "名称", name = "name", required = false, example = "")
	@EncryptCardNo
	private String name;
	/**
	 * 只读. 卡号. card_no
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "卡号", name = "cardNo", required = false, example = "")
	@EncryptCardNo
	private String cardNo;
	/**
	 * 只读. . phone
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "phone", required = false, example = "")
	@EncryptPhone
	private String phone;
	/**
	 * 只读. 充值等级. level_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "充值等级", name = "levelId", required = false, example = "")
	private Long levelId;
	/**
	 * 只读. 到期等级变更. change_level_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "到期等级变更", name = "changeLevelId", required = false, example = "")
	private Long changeLevelId;
	/**
	 * 只读. 有效期. effective_date
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "有效期", name = "effectiveDate", required = false, example = "")
	private Date effectiveDate;
	/**
	 * 只读. 数据有效性 0无效 1有效. valid
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性 0无效 1有效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 备注. remark
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人名称. create_user_name
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人名称", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建日期. create_date
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人姓名. modified_user_name
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人姓名", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改日期. modified_date
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改日期", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getLevelRechargeId() {
		return levelRechargeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setLevelRechargeId(Long levelRechargeId) {
		this.levelRechargeId = levelRechargeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getName() {
		return name;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setName(String name) {
		this.name = name == null ? null : name.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getCardNo() {
		return cardNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setCardNo(String cardNo) {
		this.cardNo = cardNo == null ? null : cardNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getPhone() {
		return phone;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setPhone(String phone) {
		this.phone = phone == null ? null : phone.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getLevelId() {
		return levelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setLevelId(Long levelId) {
		this.levelId = levelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getChangeLevelId() {
		return changeLevelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setChangeLevelId(Long changeLevelId) {
		this.changeLevelId = changeLevelId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Date getEffectiveDate() {
		return effectiveDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-04-29 20:24:07
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}
}
